@@ -50,7 +50,10 @@ class Routes:
 		for key in self._routes.iterkeys():
 			match = key.match(path)
 			if match:
-				handler_args = match.groupdict()
+				handler_args = match.groupdict()                                                                         
+				for k,v in handler_args.items():
+					if v is None: del handler_args[k]
+
 				handler = self._routes[key]
 				break
 
