@@ -30,18 +30,11 @@ from gevent.wsgi import WSGIServer as wsgi_server
 from content_types import *
 
 '''_______________________________variables__________________________________'''
-__author__		= "Justin Wilson"
-__copyright__	= "Copyright 2011, Justin Wilson"
-__credits__		= ["Justin Wilson", "Eber Irigoyen", "Corey McKinnon"]
-__license__		= "Simplified BSD License"
-__version__		= "0.1.2"
-__maintainer__	= "Justin Wilson"
-__email__		= "justinwilson1 at gmail dot com"
-__status__		= "Alpha"
 
 status_codes = BaseHTTPRequestHandler.responses
 
 '''________________________________helpers___________________________________'''
+
 def _body_wrap(content_type):
 	def normal(data):
 		return data
@@ -160,7 +153,22 @@ def handle_route(env, resp, route, kwargs):
 		resp(status(200), route.content_type)		# success
 		return body
 
+def get_handler(routes):
+	def handler(env, resp):
+		path = env.get('PATH_INFO')
+		method = env.get('REQUEST_METHOD')
+		route, kwargs = routes.get(path)
+
+		if not route:
+			return error_handler(env, resp, 404)
+		elif method != route.method and method not in route.methods:
+			return error_handler(env, resp, 501, content_type=route.content_type)
+		else:
+			return handle_route(env, resp, route, kwargs)
+	return handler
+
 '''________________________________server____________________________________'''
+
 class WSGIServer:
 	def __init__(self, addr, routes, **kwargs):
 		""" Creates a new WSGIServer using either the gevent underlying wsgi/pywsgi.
@@ -179,7 +187,7 @@ class WSGIServer:
 		else:
 			wsgi = wsgi_server
 
-		self._server = wsgi(addr, self._handler, **kwargs)
+		self._server = wsgi(addr, get_handler(routes), **kwargs)
 	
 	def _print_start_msg(self):
 		print('[gserver] {0} - listening on {1}:{2}'
@@ -190,22 +198,9 @@ class WSGIServer:
 		self._server.start()
 
 	def stop(self):
-		self._print_start_msg()
 		self._server.stop()
 
 	def serve_forever(self):
 		self._print_start_msg()
 		self._server.serve_forever()
 
-	def _handler(self, env, resp):
-		path = env.get('PATH_INFO')
-		method = env.get('REQUEST_METHOD')
-		route, kwargs = self._routes.get(path)
-
-		if not route:
-			return error_handler(env, resp, 404)
-		elif method != route.method and method not in route.methods:
-			return error_handler(env, resp, 501, content_type=route.content_type)
-		else:
-			return handle_route(env, resp, route, kwargs)
-
